@@ -65,12 +65,6 @@ namespace GtkSharp.Generation {
 			}
 		}
 
-		public bool IsNullTermArray {
-			get {
-				return elem.HasAttribute ("null_term_array");
-			}
-		}
-
 		public bool IsBitfield {
 			get {
 				return elem.HasAttribute("bits");
@@ -119,20 +113,20 @@ namespace GtkSharp.Generation {
 			SymbolTable table = SymbolTable.Table;
 
 			if (getterName != null) {
-				sw.WriteLine (indent + "[DllImport (\"{0}\", CallingConvention = CallingConvention.Cdecl)]", gen_info.GluelibName);
+				sw.WriteLine (indent + "[DllImport (\"{0}\")]", gen_info.GluelibName);
 				sw.WriteLine (indent + "extern static {0} {1} ({2} raw);",
 					      table.GetMarshalReturnType (CType), getterName,
 					      container_type.MarshalType);
 			}
 
 			if (setterName != null) {
-				sw.WriteLine (indent + "[DllImport (\"{0}\", CallingConvention = CallingConvention.Cdecl)]", gen_info.GluelibName);
+				sw.WriteLine (indent + "[DllImport (\"{0}\")]", gen_info.GluelibName);
 				sw.WriteLine (indent + "extern static void {0} ({1} raw, {2} value);",
 					      setterName, container_type.MarshalType, table.GetMarshalType (CType));
 			}
 
 			if (getOffsetName != null) {
-				sw.WriteLine (indent + "[DllImport (\"{0}\", CallingConvention = CallingConvention.Cdecl)]", gen_info.GluelibName);
+				sw.WriteLine (indent + "[DllImport (\"{0}\")]", gen_info.GluelibName);
 				sw.WriteLine (indent + "extern static uint {0} ();", getOffsetName);
 				sw.WriteLine ();
 				sw.WriteLine (indent + "static uint " + offsetName + " = " + getOffsetName + " ();");
@@ -165,14 +159,11 @@ namespace GtkSharp.Generation {
 
 			if (Getter != null) {
 				sw.Write (indent + "\tget ");
-				Getter.GenerateBody (gen_info, container_type, "\t");
+				Getter.GenerateBody (gen_info, "\t");
 				sw.WriteLine ("");
 			} else if (getterName != null) {
 				sw.WriteLine (indent + "\tget {");
-				container_type.Prepare (sw, indent + "\t\t");
-				sw.WriteLine (indent + "\t\t" + CSType + " result = " + table.FromNativeReturn (ctype, getterName + " (" + container_type.CallByName () + ")") + ";");
-				container_type.Finish (sw, indent + "\t\t");
-				sw.WriteLine (indent + "\t\treturn result;");
+				sw.WriteLine (indent + "\t\treturn " + table.FromNativeReturn (ctype, getterName + " (" + container_type.CallByName () + ")") + ";");
 				sw.WriteLine (indent + "\t}");
 			} else if (Readable && offsetName != null) {
 				sw.WriteLine (indent + "\tget {");
@@ -190,13 +181,11 @@ namespace GtkSharp.Generation {
 
 			if (Setter != null) {
 				sw.Write (indent + "\tset ");
-				Setter.GenerateBody (gen_info, container_type, "\t");
+				Setter.GenerateBody (gen_info, "\t");
 				sw.WriteLine ("");
 			} else if (setterName != null) {
 				sw.WriteLine (indent + "\tset {");
-				container_type.Prepare (sw, indent + "\t\t");
 				sw.WriteLine (indent + "\t\t" + setterName + " (" + container_type.CallByName () + ", " + table.CallByName (ctype, "value") + ");");
-				container_type.Finish (sw, indent + "\t\t");
 				sw.WriteLine (indent + "\t}");
 			} else if (Writable && offsetName != null) {
 				sw.WriteLine (indent + "\tset {");
@@ -273,3 +262,4 @@ namespace GtkSharp.Generation {
 		}
 	}
 }
+
