@@ -2,12 +2,12 @@
 //
 // Authors:
 //	Gonzalo Paniagua Javier (gonzalo@ximian.com)
-//
+//	
 //
 // Copyright (c) 2002 Gonzalo Paniagua
 //
 // This program is free software; you can redistribute it and/or
-// modify it under the terms of version 2 of the Lesser GNU General
+// modify it under the terms of version 2 of the Lesser GNU General 
 // Public License as published by the Free Software Foundation.
 //
 // This program is distributed in the hope that it will be useful,
@@ -30,10 +30,6 @@ namespace GLib {
 
 	public delegate void LogFunc (string log_domain, LogLevelFlags log_level, string message);
 
-	[UnmanagedFunctionPointer (CallingConvention.Cdecl)]
-	internal delegate void LogFunc2 (string log_domain, LogLevelFlags log_level, string message, LogFunc user_data);
-
-	[UnmanagedFunctionPointer (CallingConvention.Cdecl)]
 	public delegate void PrintFunc (string message);
 
 	[Flags]
@@ -70,19 +66,9 @@ namespace GLib {
 				handlers = new Hashtable ();
 		}
 
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libglib-2.0-0.dll")]
 		static extern void g_logv (IntPtr log_domain, LogLevelFlags flags, IntPtr message);
-
-		public static void Write (string logDomain, LogLevelFlags flags, string format, params object [] args)
-		{
-			IntPtr ndom = Marshaller.StringToPtrGStrdup (logDomain);
-			IntPtr nmessage = Marshaller.StringToPtrGStrdup (String.Format (format, args));
-			g_logv (ndom, flags, nmessage);
-			Marshaller.Free (ndom);
-			Marshaller.Free (nmessage);
-		}
-
-		[Obsolete ("Use the static member Write")]
+		
 		public void WriteLog (string logDomain, LogLevelFlags flags, string format, params object [] args)
 		{
 			IntPtr ndom = Marshaller.StringToPtrGStrdup (logDomain);
@@ -92,17 +78,13 @@ namespace GLib {
 			Marshaller.Free (nmessage);
 		}
 
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
-		static extern uint g_log_set_handler (IntPtr log_domain, LogLevelFlags flags, LogFunc2 log_func, LogFunc user_data);
-
-		static readonly LogFunc2 LogFuncTrampoline = (string domain, LogLevelFlags level, string message, LogFunc user_data) => {
-                        user_data (domain, level, message);
-                };
-
+		[DllImport("libglib-2.0-0.dll")]
+		static extern uint g_log_set_handler (IntPtr log_domain, LogLevelFlags flags, LogFunc log_func, IntPtr user_data);
+		
 		public static uint SetLogHandler (string logDomain, LogLevelFlags flags, LogFunc logFunc)
 		{
 			IntPtr ndom = Marshaller.StringToPtrGStrdup (logDomain);
-			uint result = g_log_set_handler (ndom, flags, LogFuncTrampoline, logFunc);
+			uint result = g_log_set_handler (ndom, flags, logFunc, IntPtr.Zero);
 			Marshaller.Free (ndom);
 			EnsureHash ();
 			handlers [result] = logFunc;
@@ -110,21 +92,21 @@ namespace GLib {
 			return result;
 		}
 
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libglib-2.0-0.dll")]
 		static extern uint g_log_remove_handler (IntPtr log_domain, uint handler_id);
 
 		public static void RemoveLogHandler (string logDomain, uint handlerID)
 		{
 			if (handlers != null && handlers.ContainsKey (handlerID))
 				handlers.Remove (handlerID);
-
+			
 			IntPtr ndom = Marshaller.StringToPtrGStrdup (logDomain);
 			g_log_remove_handler (ndom, handlerID);
 			Marshaller.Free (ndom);
 		}
 
 
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libglib-2.0-0.dll")]
 		static extern PrintFunc g_set_print_handler (PrintFunc handler);
 
 		public static PrintFunc SetPrintHandler (PrintFunc handler)
@@ -134,8 +116,8 @@ namespace GLib {
 
 			return g_set_print_handler (handler);
 		}
-
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		
+		[DllImport("libglib-2.0-0.dll")]
 		static extern PrintFunc g_set_printerr_handler (PrintFunc handler);
 
 		public static PrintFunc SetPrintErrorHandler (PrintFunc handler)
@@ -145,12 +127,12 @@ namespace GLib {
 
 			return g_set_printerr_handler (handler);
 		}
-
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		
+		[DllImport("libglib-2.0-0.dll")]
 		static extern void g_log_default_handler (IntPtr log_domain, LogLevelFlags log_level, IntPtr message, IntPtr unused_data);
 
 		public static void DefaultHandler (string logDomain, LogLevelFlags logLevel, string message)
-
+						   
 		{
 			IntPtr ndom = Marshaller.StringToPtrGStrdup (logDomain);
 			IntPtr nmess = Marshaller.StringToPtrGStrdup (message);
@@ -159,17 +141,17 @@ namespace GLib {
 			Marshaller.Free (nmess);
 		}
 
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libglib-2.0-0.dll")]
 		extern static LogLevelFlags g_log_set_always_fatal (LogLevelFlags fatal_mask);
-
+		
 		public static LogLevelFlags SetAlwaysFatal (LogLevelFlags fatalMask)
 		{
 			return g_log_set_always_fatal (fatalMask);
 		}
 
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libglib-2.0-0.dll")]
 		extern static LogLevelFlags g_log_set_fatal_mask (IntPtr log_domain, LogLevelFlags fatal_mask);
-
+		
 		public static LogLevelFlags SetAlwaysFatal (string logDomain, LogLevelFlags fatalMask)
 		{
 			IntPtr ndom = Marshaller.StringToPtrGStrdup (logDomain);
@@ -206,3 +188,4 @@ namespace GLib {
 		}
 	}
 }
+
